@@ -1,5 +1,5 @@
 package App::Wallflower;
-$App::Wallflower::VERSION = '1.006';
+$App::Wallflower::VERSION = '1.007';
 use strict;
 use warnings;
 
@@ -23,20 +23,22 @@ sub _default_options {
 
 # [ activating option, coderef ]
 my @callbacks = (
-    [   errors => sub {
+    [
+        errors => sub {
             my ( $url, $response ) = @_;
             my ( $status, $headers, $file ) = @$response;
             return if $status == 200;
-            printf "$status %s%s\n", $url->path,
-                $file && " => $file [${\-s $file}]";
-            }
-    ], [verbose => sub {
+            printf "$status %s%s\n", $url->path;
+        },
+    ],
+    [
+        verbose => sub {
             my ( $url, $response ) = @_;
             my ( $status, $headers, $file ) = @$response;
             return if $status != 200;
             printf "$status %s%s\n", $url->path,
-                $file && " => $file [${\-s $file}]";
-            }
+              $file && " => $file [${\-s $file}]";
+        },
     ],
 );
 
@@ -210,8 +212,6 @@ sub _host_regexp {
 
 1;
 
-# ABSTRACT: Class performing the moves for the wallflower program
-
 __END__
 
 =pod
@@ -220,10 +220,6 @@ __END__
 
 App::Wallflower - Class performing the moves for the wallflower program
 
-=head1 VERSION
-
-version 1.006
-
 =head1 SYNOPSIS
 
     # this is the actual code for wallflower
@@ -235,23 +231,25 @@ version 1.006
 L<App::Wallflower> is a container for functions for the L<wallflower>
 program.
 
-=head1 METHODS
+=head2 new_with_options
 
-=head2 new_with_options( \@argv )
+    App::Wallflower->new_with_options( \@ARGV );
 
 Process options in the provided array reference (modifying it),
 and return a object ready to be C<run()>.
 
 See L<wallflower> for the list of options and their usage.
 
-=head2 new( option => \%option, args => \@args )
+=head2 new
+
+    App::Wallflower->new( option => \%option, args => \@args );
 
 Create an object ready to be C<run()>.
 
 C<option> is a hashref of options as produced by L<Getopt::Long>, and
 C<args> is an array ref of optional arguments to be processed by C<run()>
 
-=head2 run( )
+=head2 run
 
 Make L<wallflower> dance.
 
@@ -264,9 +262,10 @@ Philippe Bruhat (BooK) <book@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Philippe Bruhat (BooK).
+Copyright 2012-2015 by Philippe Bruhat (BooK).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
