@@ -1,5 +1,5 @@
 package Wallflower;
-$Wallflower::VERSION = '1.006';
+$Wallflower::VERSION = '1.007';
 use strict;
 use warnings;
 
@@ -124,9 +124,17 @@ sub get {
 
         # get a file to save the content in
         my $dir = ( $file = $target )->dir;
-        $dir->mkpath if !-e $dir;
+        if ( !-e $dir ) {
+            eval { $dir->mkpath } or do {
+                warn "$@\n" if $@;
+                return [ 999, [], '' ];
+            };
+        }
         open my $fh, '> :raw', $file    # no stinky crlf on Win32
-          or croak "Can't open $file for writing: $!";
+          or do {
+            warn "Can't open $file for writing: $!\n";
+            return [ 999, [], '' ];
+          };
 
         # copy content to the file
         if ( ref $content eq 'ARRAY' ) {
@@ -157,8 +165,6 @@ sub get {
 
 1;
 
-# ABSTRACT: Stick Plack applications to the wallpaper
-
 __END__
 
 =pod
@@ -167,10 +173,6 @@ __END__
 
 Wallflower - Stick Plack applications to the wallpaper
 
-=head1 VERSION
-
-version 1.006
-
 =head1 SYNOPSIS
 
     use Wallflower;
@@ -190,7 +192,9 @@ save the corresponding response to a file.
 
 =head1 METHODS
 
-=head2 new( %args )
+=head2 new
+
+    my $w = Wallflower->new( %args );
 
 Create a new L<Wallflower> object.
 
@@ -228,7 +232,9 @@ that position.
 
 =back
 
-=head2 get( $url )
+=head2 get
+
+    my $response = $w->get( $url );
 
 Perform a C<GET> request for C<$url> through the application, and
 if successful, save the result to a filename derived from C<$url> by
@@ -238,7 +244,7 @@ C<$url> can be either a string or a L<URI> object, representing an
 absolute URL (the path must start with a C</>). The scheme, host, port,
 and query string are ignored if present.
 
-The return value is very similar to a L<Plack> application's:
+The return value is very similar to a L<Plack> application response:
 
    [ $status, $headers, $file ]
 
@@ -246,13 +252,19 @@ where C<$status> and C<$headers> are those returned by the application
 itself for the given C<$url>, and C<$file> is the name of the file where
 the content has been saved.
 
+If an error is encountered when trying to open the file, C<$status>
+will be set to C<999> (an invalid HTTP status code), and a warning will
+be emitted.
+
 If a file exists at the location pointed to by the target, a
 C<If-Modified-Since> header is added to the Plack environment,
 with the modification timestamp for this file as the value.
 If the application sends a C<304 Not modified> in response,
 the target file will not be modified.
 
-=head2 target( $uri )
+=head2 target
+
+    my $target = $w->target($uri);
 
 Return the filename where the content of C<$uri> will be saved.
 
@@ -274,9 +286,10 @@ Philippe Bruhat (BooK) <book@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Philippe Bruhat (BooK).
+Copyright 2012-2015 by Philippe Bruhat (BooK).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
