@@ -1,5 +1,5 @@
 package Wallflower::Util;
-$Wallflower::Util::VERSION = '1.006';
+$Wallflower::Util::VERSION = '1.007';
 use strict;
 use warnings;
 
@@ -60,8 +60,6 @@ sub _links_from_css {
 
 1;
 
-# ABSTRACT: Utility functions for Wallflower
-
 __END__
 
 =pod
@@ -70,10 +68,6 @@ __END__
 
 Wallflower::Util - Utility functions for Wallflower
 
-=head1 VERSION
-
-version 1.006
-
 =head1 SYNOPSIS
 
     use Wallflower;
@@ -93,7 +87,9 @@ produced by L<Wallflower>'s C<get()> method.
 
 =head1 FUNCTIONS
 
-=head2 links_from( $response, $url )
+=head2 links_from
+
+    my @links = links_from( $response, $url );
 
 Returns all links found in the response body, depending on its content type.
 
@@ -107,9 +103,10 @@ Philippe Bruhat (BooK) <book@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Philippe Bruhat (BooK).
+Copyright 2012-2015 by Philippe Bruhat (BooK).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
